@@ -30,8 +30,8 @@ removeEmptyMassObjects <- function(l) {
   .stopIfNotIsMassObjectList(l)
 
   ## find empty MassPeaks objects
-  notEmpty <- !(1:length(l) %in% findEmptyMassObjects(l))
+  notEmpty <- !(seq_along(l) %in% findEmptyMassObjects(l))
 
   ## exclude empty elements
-  return(l[notEmpty])
+  l[notEmpty]
 }
